==> mongodb_2.6.10.orig.tar.gz: mongodb-src-r2.6.10/src/mongo/util/fail_point_service.cpp <==
/*
 *    Copyright (C) 2012 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#include "mongo/util/fail_point_service.h"

namespace mongo {
    MONGO_FP_DECLARE(dummy); // used by jstests/libs/fail_point.js

    scoped_ptr<FailPointRegistry> _fpRegistry(NULL);

    MONGO_INITIALIZER(FailPointRegistry)(InitializerContext* context) {
        _fpRegistry.reset(new FailPointRegistry());
        return Status::OK();
    }

    MONGO_INITIALIZER_GENERAL(AllFailPointsRegistered,
                              MONGO_NO_PREREQUISITES,
                              MONGO_NO_DEPENDENTS)(InitializerContext* context) {
        _fpRegistry->freeze();
        return Status::OK();
    }

    FailPointRegistry* getGlobalFailPointRegistry() {
        return _fpRegistry.get();
    }
}

==> mongodb_3.4.1.orig.tar.gz: mongodb-src-r3.4.1/src/mongo/util/fail_point_service.cpp <==
/*
 *    Copyright (C) 2012 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#include "mongo/util/fail_point_service.h"


namespace mongo {

using std::unique_ptr;

MONGO_FP_DECLARE(dummy);  // used by tests in jstests/fail_point

unique_ptr<FailPointRegistry> _fpRegistry(nullptr);

MONGO_INITIALIZER_WITH_PREREQUISITES(FailPointRegistry, MONGO_NO_PREREQUISITES)
(InitializerContext* context) {
    _fpRegistry.reset(new FailPointRegistry());
    return Status::OK();
}

MONGO_INITIALIZER_GENERAL(AllFailPointsRegistered, MONGO_NO_PREREQUISITES, MONGO_NO_DEPENDENTS)
(InitializerContext* context) {
    _fpRegistry->freeze();
    return Status::OK();
}

FailPointRegistry* getGlobalFailPointRegistry() {
    return _fpRegistry.get();
}
}
